.. automodapi:: radiospectra.spectrogram2
    :include-all-objects:

.. automodapi:: radiospectra.spectrogram2.spectrogram

.. automodapi:: radiospectra.spectrogram2.sources
    :include-all-objects:
